<?php defined('SYSPATH') or die('No direct access allowed.');

class Model_Role extends Model_Auth_Role {

	// This class can be replaced or extended

} // End Role Model